==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/de.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Du kannst deine eigene Leseberechtigung nicht entfernen.",
    "Team folders" : "Team-Ordner",
    "Admin configured folders shared with everyone in a team" : "Von der Administration konfigurierte Ordner, die für alle in einem Team freigegeben sind",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Von der Administration konfigurierte Ordner, die für alle Mitglieder eines Teams freigegeben sind.\n\nOrdner können unter *Teamordner* in den Administrationseinstellungen konfiguriert werden.\n\nNachdem ein Ordner erstellt wurde, kann die Administration einem oder mehreren Teams Zugriff auf den Ordner gewähren, ihre Schreib-/Freigabeberechtigungen steuern und ein Speicherkontingent für den Ordner zuweisen.\nAb Hub 10/Nextcloud 31 muss die Administration Teil des Teams sein, um einen Teamordner zuweisen zu können.",
    "Unset" : "Entfernt",
    "Denied (Inherited permission)" : "Verweigert (Vererbte Berechtigung)",
    "Allowed (Inherited permission)" : "Zugelassen (Vererbte Berechtigung)",
    "Denied" : "Verweigert",
    "Allowed" : "Zugelassen",
    "Access denied" : "Zugriff verweigert",
    "Access allowed" : "Zugriff erlaubt",
    "Inherit permission" : "Berechtigung vererben",
    "Deny" : "Verweigern",
    "Allow" : "Erlauben",
    "Group" : "Gruppe",
    "Team" : "Team",
    "Team folder" : "Team-Ordner",
    "Read" : "Lesen",
    "Write" : "Schreiben",
    "Create" : "Erstellen",
    "Delete" : "Löschen",
    "Share" : "Freigeben",
    "You" : "Du",
    "Remove access rule" : "Zugriffsregel entfernen",
    "Add advanced permission rule" : "Erweiterte Berechtigungsregel hinzufügen",
    "Select a user or group" : "Benutzer oder Gruppe wählen",
    "Open Team folder" : "Team-Ordner öffnen",
    "Permission denied. User does not have sufficient permissions." : "Berechtigung verweigert. Benutzer verfügt nicht über die erforderlichen Berechtigungen.",
    "Unexpected status from server" : "Unerwarteter Status vom Server",
    "List of Team folders." : "Liste der Team-Ordner.",
    "No Team folders yet" : "Bislang keine Team-Ordner",
    "Team folders will show up here" : "Team-Ordner werden hier angezeigt",
    "Add group" : " Gruppe hinzufügen ",
    "Default" : "Standard",
    "Unlimited" : "Unbegrenzt",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Bist du sicher, dass du \"{folderName}\" und alle enthaltenen Dateien löschen möchtest? Dieser Vorgang kann nicht rückgängig gemacht werden!",
    "Delete \"{folderName}\"?" : " \"{folderName}\" löschen?",
    "Team folder admin delegation" : "Administrationsrechte-Übertragung für Team-Ordner",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Mit Nextcloud kann die die Verwaltung von Teamordnern an Benutzer ohne Administrationsrechte delegiert werden.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Unten bitte die Gruppen angeben, die Teamordner verwalten und deren API/REST verwenden dürfen.",
    "They will have access to all Team folders." : "Sie werden Zugriff auf alle Team-Ordner haben.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Unten bitte die Gruppen angeben, die Teamordner verwalten und nur deren API/REST verwenden dürfen.",
    "They will only have access to Team folders for which they have advanced permissions." : "Du hast dann nur Zugriff auf Team-Ordner, für die du erweiterte Rechte hast.",
    "Group or team" : "Gruppe oder Team",
    "Sort by number of groups or teams that have access to this folder" : "Sortieren nach Anzahl der Gruppen oder Teams, die Zugriff auf diesen Ordner haben",
    "Sort by number of groups that have access to this folder" : "Sortieren nach Anzahl der Gruppen, die Zugriff auf diesen Ordner haben",
    "Folder name" : "Ordnername",
    "Quota" : "Kontingent",
    "Advanced Permissions" : "Erweiterte Berechtigungen",
    "Pagination of team folders" : "Mehrseitige Liste von Teamordnern",
    "Previous" : "Zurück",
    "Next" : "Nächstes",
    "User" : "Benutzer",
    "Unknown" : "Unbekannt",
    "Users/groups that can manage" : "Benutzer/Gruppen, die verwalten können",
    "None" : "Keine",
    "No other groups or teams available" : "Keine anderen Gruppen oder Teams verfügbar",
    "No other groups available" : "Keine anderen Gruppen verfügbar",
    "{displayName} (team)" : "{displayName} (Team)",
    "Add group or team" : "Gruppe oder Team hinzufügen",
    "{size} used" : "{size} verwendet",
    "Other …" : "Andere...",
    "You can not remove your own read permission." : "Du kannst deine eigene Leseberechtigung nicht entfernen.",
    "Group folders" : "Gruppenordner",
    "Admin configured folders shared with everyone in a group" : "Von der Administration konfigurierte Ordner, die für jeden in einer Gruppe freigegeben sind",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Von der Administration konfigurierte Ordner, die mit allen Mitgliedern einer Gruppe geteilt werden.\n\nOrdner können in den Administrationseinstellungen unter *Gruppenordner* konfiguriert werden.\n\nNachdem ein Ordner erstellt wurde, kann die Administration einer oder mehreren Gruppen Zugriff auf den Ordner gewähren, ihre Schreib-/Freigabeberechtigungen steuern und dem Ordner ein Kontingent zuweisen.",
    "Group folder" : "Gruppenordner",
    "Open group folder" : "Gruppenordner öffnen",
    "List of group folders." : "Liste der Gruppenordner.",
    "No group folders yet" : "Bis jetzt keine Gruppenordner",
    "Group folders will show up here" : "Gruppenordner werden hier angezeigt",
    "Group folder admin delegation" : "Gruppenordner Administrationsrechteübertragung",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Mit Nextcloud kann die Verwaltung von Gruppenordnern an Benutzer ohne Administrationsrechte delegiert werden.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Unten bitte die Gruppen angeben, die Gruppenordner verwalten und deren API/REST verwenden dürfen.",
    "They will have access to all group folders." : "Du wirst Zugriff auf alle Gruppenordner haben.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Unten bitte die Gruppen angeben, die Gruppenordner verwalten und nur deren API/REST verwenden dürfen.",
    "They will only have access to group folders for which they have advanced permissions." : "Du hast nur Zugriff auf Gruppenordner, für die du erweiterte Rechte hast.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Von der Administration konfigurierte Ordner, die mit allen Mitgliedern eines Teams geteilt werden.\n\nOrdner können in den Administrationseinstellungen unter *Team-Ordner* konfiguriert werden.\n\nNachdem ein Ordner erstellt wurde, kann die Administration einem oder mehreren Teams Zugriff auf den Ordner gewähren, ihre Schreib-/Freigabeberechtigungen steuern und dem Ordner ein Kontingent zuweisen."
},
"nplurals=2; plural=(n != 1);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/de.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Du kannst deine eigene Leseberechtigung nicht entfernen.",
    "Team folders" : "Team-Ordner",
    "Unset" : "Entfernt",
    "Denied (Inherited permission)" : "Verweigert (Vererbte Berechtigung)",
    "Allowed (Inherited permission)" : "Zugelassen (Vererbte Berechtigung)",
    "Denied" : "Verweigert",
    "Allowed" : "Zugelassen",
    "Access denied" : "Zugriff verweigert",
    "Access allowed" : "Zugriff erlaubt",
    "Inherit permission" : "Berechtigung vererben",
    "Deny" : "Verweigern",
    "Allow" : "Erlauben",
    "Group" : "Gruppe",
    "Team" : "Team",
    "Team folder" : "Team-Ordner",
    "Read" : "Lesen",
    "Write" : "Schreiben",
    "Create" : "Erstellen",
    "Delete" : "Löschen",
    "Share" : "Freigeben",
    "You" : "Du",
    "Remove access rule" : "Zugriffsregel entfernen",
    "Add advanced permission rule" : "Erweiterte Berechtigungsregel hinzufügen",
    "Select a user or group" : "Benutzer oder Gruppe wählen",
    "Open Team folder" : "Team-Ordner öffnen",
    "Permission denied. User does not have sufficient permissions." : "Berechtigung verweigert. Benutzer verfügt nicht über die erforderlichen Berechtigungen.",
    "Unexpected status from server" : "Unerwarteter Status vom Server",
    "List of Team folders." : "Liste der Team-Ordner.",
    "No Team folders yet" : "Bislang keine Team-Ordner",
    "Team folders will show up here" : "Team-Ordner werden hier angezeigt",
    "Add group" : " Gruppe hinzufügen ",
    "Default" : "Standard",
    "Unlimited" : "Unbegrenzt",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Bist du sicher, dass du \"{folderName}\" und alle enthaltenen Dateien löschen möchtest? Dieser Vorgang kann nicht rückgängig gemacht werden!",
    "Delete \"{folderName}\"?" : " \"{folderName}\" löschen?",
    "Team folder admin delegation" : "Administrationsrechte-Übertragung für Team-Ordner",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Mit Nextcloud kann die die Verwaltung von Teamordnern an Benutzer ohne Administrationsrechte delegiert werden.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Unten bitte die Gruppen angeben, die Teamordner verwalten und deren API/REST verwenden dürfen.",
    "They will have access to all Team folders." : "Sie werden Zugriff auf alle Team-Ordner haben.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Unten bitte die Gruppen angeben, die Teamordner verwalten und nur deren API/REST verwenden dürfen.",
    "They will only have access to Team folders for which they have advanced permissions." : "Du hast dann nur Zugriff auf Team-Ordner, für die du erweiterte Rechte hast.",
    "Group or team" : "Gruppe oder Team",
    "Sort by number of groups or teams that have access to this folder" : "Sortieren nach Anzahl der Gruppen oder Teams, die Zugriff auf diesen Ordner haben",
    "Sort by number of groups that have access to this folder" : "Sortieren nach Anzahl der Gruppen, die Zugriff auf diesen Ordner haben",
    "Folder name" : "Ordnername",
    "Quota" : "Kontingent",
    "Advanced Permissions" : "Erweiterte Berechtigungen",
    "Pagination of team folders" : "Mehrseitige Liste von Teamordnern",
    "Previous" : "Zurück",
    "Next" : "Nächstes",
    "User" : "Benutzer",
    "Unknown" : "Unbekannt",
    "Users/groups that can manage" : "Benutzer/Gruppen, die verwalten können",
    "None" : "Keine",
    "No other groups or teams available" : "Keine anderen Gruppen oder Teams verfügbar",
    "No other groups available" : "Keine anderen Gruppen verfügbar",
    "{displayName} (team)" : "{displayName} (Team)",
    "Add group or team" : "Gruppe oder Team hinzufügen",
    "{size} used" : "{size} verwendet",
    "Other …" : "Andere...",
    "You can not remove your own read permission." : "Du kannst deine eigene Leseberechtigung nicht entfernen.",
    "Group folders" : "Gruppenordner",
    "Admin configured folders shared with everyone in a group" : "Von der Administration konfigurierte Ordner, die für jeden in einer Gruppe freigegeben sind",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Von der Administration konfigurierte Ordner, die mit allen Mitgliedern einer Gruppe geteilt werden.\n\nOrdner können in den Administrationseinstellungen unter *Gruppenordner* konfiguriert werden.\n\nNachdem ein Ordner erstellt wurde, kann die Administration einer oder mehreren Gruppen Zugriff auf den Ordner gewähren, ihre Schreib-/Freigabeberechtigungen steuern und dem Ordner ein Kontingent zuweisen.",
    "Group folder" : "Gruppenordner",
    "Open group folder" : "Gruppenordner öffnen",
    "List of group folders." : "Liste der Gruppenordner.",
    "No group folders yet" : "Bis jetzt keine Gruppenordner",
    "Group folders will show up here" : "Gruppenordner werden hier angezeigt",
    "Group folder admin delegation" : "Gruppenordner Administrationsrechteübertragung",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Mit Nextcloud kann die Verwaltung von Gruppenordnern an Benutzer ohne Administrationsrechte delegiert werden.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Unten bitte die Gruppen angeben, die Gruppenordner verwalten und deren API/REST verwenden dürfen.",
    "They will have access to all group folders." : "Du wirst Zugriff auf alle Gruppenordner haben.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Unten bitte die Gruppen angeben, die Gruppenordner verwalten und nur deren API/REST verwenden dürfen.",
    "They will only have access to group folders for which they have advanced permissions." : "Du hast nur Zugriff auf Gruppenordner, für die du erweiterte Rechte hast.",
    "Admin configured folders shared with everyone in a team" : "Von der Administration konfigurierte Ordner, die für alle in einem Team freigegeben sind",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Von der Administration konfigurierte Ordner, die mit allen Mitgliedern eines Teams geteilt werden.\n\nOrdner können in den Administrationseinstellungen unter *Team-Ordner* konfiguriert werden.\n\nNachdem ein Ordner erstellt wurde, kann die Administration einem oder mehreren Teams Zugriff auf den Ordner gewähren, ihre Schreib-/Freigabeberechtigungen steuern und dem Ordner ein Kontingent zuweisen.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Von der Administration konfigurierte Ordner, die für alle Mitglieder eines Teams freigegeben sind.\n\nOrdner können unter *Teamordner* in den Administrationseinstellungen konfiguriert werden.\n\nNachdem ein Ordner erstellt wurde, kann die Administration einem oder mehreren Teams Zugriff auf den Ordner gewähren, ihre Schreib-/Freigabeberechtigungen steuern und ein Speicherkontingent für den Ordner zuweisen.\nAb Hub 10/Nextcloud 31 muss die Administration Teil des Teams sein, um einen Teamordner zuweisen zu können."
},
"nplurals=2; plural=(n != 1);");
